@@ -35,7 +35,7 @@ def _parser():
     """The parser"""
     desc = (
         f"mokapot version {__version__}.\n"
-        "Written by William E. Fondrie (wfondrie@uw.edu) in the \n"
+        "Written by William E. Fondrie (wfondrie@talus.bio) while in the \n"
         "Department of Genome Sciences at the University of Washington.\n\n"
         "Official code website: https://github.com/wfondrie/mokapot\n\n"
         "More documentation and examples: https://mokapot.readthedocs.io"
@@ -252,6 +252,21 @@ def _parser():
         help=("Save the models learned by mokapot as pickled Python objects."),
     )
 
+    parser.add_argument(
+        "--load_models",
+        type=str,
+        nargs="+",
+        help=(
+            "Load previously saved models and skip model training."
+            "Note that the number of models must match the value of --folds."
+            "If the models are being applied to the same dataset that they "
+            "were trained on originally, the models must be provided in the "
+            "same order as the folds to maintain cross-vaildation fold "
+            "relationships. Failure to do so will result in invalid FDR "
+            "estimates."
+        ),
+    )
+
     parser.add_argument(
         "--keep_decoys",
         default=False,
